==> download-file.html?path=Astroid%2BPlugin%252Fastroid_3_0_14.zip: astroid-framework-master/README.md <==
[![Github All Releases](https://img.shields.io/github/downloads/templaza/astroid-framework/total.svg)](https://github.com/templaza/astroid-framework/releases)
[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](http://www.gnu.org/licenses/gpl-3.0)
[![GitHub release](https://img.shields.io/github/release/templaza/astroid-framework.svg)](https://github.com/templaza/astroid-framework/releases)
[![Discord](https://img.shields.io/badge/chat-on%20discord-7289da.svg)](https://discord.gg/2MwtsAX4Py)
[![Donate](https://img.shields.io/badge/donate-Buy%20me%20a%20coffee-blueviolet)](https://www.paypal.com/paypalme/sonvnn)

# Astroid Framework - Powerful Joomla Template Framework

[Watch Intro Video here](https://www.youtube.com/watch?v=ZflNq3fDaXE)

## Features
* Bootstrap 5 Compatible
* Built for Joomla 4 and Joomla 5
* Drag and Drop Layout Builder
* Advanced Responsive Control
* Advanced Mega Menu
* Off-Canvas Menu
* Advanced Typography Controls
* Child-Template Support
* Advanced Blog Options
* Unlimited Custom Code
* Logo and Header Options
* Enhanced User Experience
* Import/Export Settings
* Only Enable What You Need
* Font Awesome 6
* Social Icons & Share
* Sass ready
* Responsive & Accessible Design
* Refactored Codebase
* RTL Support
* Light & Dark Color Mode
* SVG Logo Support
* Customize Breakpoint
* Many widgets integrated

## Widgets
* Articles Widget
* Banner Widget
* Button Widget
* Divider Widget
* Grid Widget
* Heading Widget
* Icons Widget
* Image Widget
* Image Group Widget
* Navigation Widget
* Slideshow Widget
* Text Widget
* Video Button Widget

## Requirements
* Joomla: 4.x, 5.x
* PHP : 8.0+

## Browser Support
| ![Chrome](https://raw.githubusercontent.com/alrra/browser-logos/master/src/chrome/chrome_48x48.png)|![Firefox](https://raw.githubusercontent.com/alrra/browser-logos/master/src/firefox/firefox_48x48.png)|![Edge](https://raw.githubusercontent.com/alrra/browser-logos/master/src/edge/edge_48x48.png)|![Safari](https://raw.githubusercontent.com/alrra/browser-logos/master/src/safari/safari_48x48.png)|
| :---: | :---:	|:---:|:---:|
| &nbsp;&nbsp;Chrome 64+&nbsp;&nbsp; | &nbsp;&nbsp;Firefox 58+&nbsp;&nbsp; | &nbsp;&nbsp;Edge 14+&nbsp;&nbsp; | &nbsp;&nbsp;Safari 10+ &nbsp;&nbsp; |

## How to install
1. [Download Astroid Latest](https://github.com/templaza/astroid-framework/releases/latest)
2. Go to Joomla Administrator -> System -> Install Extensions -> Upload Package File
3. Upload 'astroid-package-v.x.x.Framework-Template.zip'
4. Back to System -> Templates -> Site Template Styles
5. Find one of Astroid template make it default
6. Go to front-end and check it.

## Links
* [Homepage](https://astroidframe.work/) - Learn more about Astroid
* [Documentation](https://docs.astroidframe.work/) - How to use Astroid
* [Translations](https://github.com/templaza/astroid-framework/tree/language) - Join to translate Astroid
* [Changelogs](https://github.com/templaza/astroid-framework/releases) - View our Changelogs
* [Discord Chat](https://discord.gg/2MwtsAX4Py) - Join our developer chat on Discord.

## Find an Astroid Template provider
* [TemPlaza - Joomla Template](https://www.templaza.com/joomla-templates.html)
* [JoomlaPlate - Joomla Template](https://www.joomlaplates.com/)

## You love this project
* [Buy me a coffee](https://www.paypal.com/paypalme/sonvnn)

==> download-file.html?path=Astroid%2BPlugin%252Fastroid_3_1_6.zip: astroid-framework-master/README.md <==
[![Github All Releases](https://img.shields.io/github/downloads/templaza/astroid-framework/total.svg)](https://github.com/templaza/astroid-framework/releases)
[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](http://www.gnu.org/licenses/gpl-3.0)
[![GitHub release](https://img.shields.io/github/release/templaza/astroid-framework.svg)](https://github.com/templaza/astroid-framework/releases)
[![Discord](https://img.shields.io/badge/chat-on%20discord-7289da.svg)](https://discord.gg/2MwtsAX4Py)
[![Donate](https://img.shields.io/badge/donate-Buy%20me%20a%20coffee-blueviolet)](https://ko-fi.com/astroidframework)

# Astroid Framework - Powerful Joomla Template Framework

[Watch Intro Video here](https://www.youtube.com/watch?v=ZflNq3fDaXE)

## Features
* Bootstrap 5 Compatible
* Built for Joomla 4 and Joomla 5
* Drag and Drop Layout Builder
* Article Layout Builder
* Sub-layouts Builder
* Advanced Responsive Control
* Advanced Mega Menu
* Off-Canvas Menu
* Advanced Typography Controls
* Child-Template Support
* Advanced Blog Options
* Unlimited Custom Code
* Logo and Header Options
* Enhanced User Experience
* Import/Export Settings
* Only Enable What You Need
* Font Awesome 6
* Social Icons & Share
* Sass ready
* Responsive & Accessible Design
* Refactored Codebase
* RTL Support
* Light & Dark Color Mode
* Transform Color Mode (Light to Dark or Dark to Light)
* SVG Logo Support
* Customize Breakpoint
* Many widgets integrated

## Widgets
* Articles Widget
* Banner Widget
* Button Widget
* Divider Widget
* Grid Widget
* Heading Widget
* Icons Widget
* Image Widget
* Image Group Widget
* Navigation Widget
* Slideshow Widget
* Text Widget
* Video Button Widget
* Video Widget
* FormBuilder Widget
* List Widget
* Testimonials Widget
* Map Widget
* Accordion Widget
* Hover Motion Widget
* CodePen Widget
* [View all Widgets](https://astroidframe.work/widgets)

## Article Widgets
* Author Info
* Comments
* Content
* Events
* Full Image
* Full Text
* Infoblock
* Intro Text
* Links
* Page Heading
* Pagination
* Related Posts
* Social Share
* Tags
* Text
* Title
* Toc

## Requirements
* Joomla: 4.x, 5.x
* PHP : 8.1+

## Browser Support
| ![Chrome](https://raw.githubusercontent.com/alrra/browser-logos/master/src/chrome/chrome_48x48.png)|![Firefox](https://raw.githubusercontent.com/alrra/browser-logos/master/src/firefox/firefox_48x48.png)|![Edge](https://raw.githubusercontent.com/alrra/browser-logos/master/src/edge/edge_48x48.png)|![Safari](https://raw.githubusercontent.com/alrra/browser-logos/master/src/safari/safari_48x48.png)|
| :---: | :---:	|:---:|:---:|
| &nbsp;&nbsp;Chrome 64+&nbsp;&nbsp; | &nbsp;&nbsp;Firefox 58+&nbsp;&nbsp; | &nbsp;&nbsp;Edge 14+&nbsp;&nbsp; | &nbsp;&nbsp;Safari 10+ &nbsp;&nbsp; |

## How to install

1. Go to Joomla Administrator -> System -> Install Extensions -> Install from Web
2. On search box type "astroid" -> Enter -> You can see "Astroid Framework" right below
3. Click and install it. -> Click "Get Started" Button
4. Install one of Astroid template & make it default
5. Go to front-end and check it.

## Links
* [Homepage](https://astroidframe.work/) - Learn more about Astroid
* [Documentation](https://docs.astroidframe.work/) - How to use Astroid
* [Roadmap](https://github.com/orgs/templaza/projects/3/views/4?sortedBy%5Bdirection%5D=desc&sortedBy%5BcolumnId%5D=Milestone) - See our roadmap
* [Changelogs](https://github.com/templaza/astroid-framework/releases) - View our Changelogs
* [Join our Community](https://www.facebook.com/groups/astroid) - Come and share with us.
* [Discord Chat](https://discord.gg/2MwtsAX4Py) - Join our developer chat on Discord.

## Find an Astroid Template provider
* [TemPlaza - Joomla Template](https://www.templaza.com/joomla-templates.html)
* [JoomlaPlate - Joomla Template](https://www.joomlaplates.com/)

## You love this project
* [Buy me a coffee](https://ko-fi.com/astroidframework)
